==> open-xchange-messaging-json_6.16.1.0.orig.tar.gz: open-xchange-messaging-json-6.16.1.0/test/com/openexchange/messaging/json/actions/services/AllActionTest.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messaging.json.actions.services;

import junit.framework.TestCase;
import org.json.JSONArray;
import org.json.JSONException;
import com.openexchange.ajax.requesthandler.AJAXRequestResult;
import com.openexchange.groupware.AbstractOXException;
import com.openexchange.i18n.Translator;
import com.openexchange.messaging.MessagingException;
import com.openexchange.messaging.SimMessagingService;
import com.openexchange.messaging.registry.SimMessagingServiceRegistry;


/**
 * {@link AllActionTest}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class AllActionTest extends TestCase {
    // Success Case
    public void testSuccess() throws AbstractOXException, JSONException {
        SimMessagingServiceRegistry registry = new SimMessagingServiceRegistry();
    
        SimMessagingService messagingService = new SimMessagingService();
        messagingService.setId("com.openexchange.test");
        
        registry.add(messagingService);
        
        AllAction action = new AllAction(registry, Translator.EMPTY);
        
        AJAXRequestResult result = action.perform(null, null);
        
        assertNotNull(result);
        
        Object resultObject = result.getResultObject();
        assertNotNull(resultObject);
        
        assertTrue(JSONArray.class.isInstance(resultObject));
    
        JSONArray all = (JSONArray) resultObject;
        assertEquals(1, all.length());
    }
    
    // Error Cases
    
    public void testMessagingException() throws AbstractOXException {
        SimMessagingServiceRegistry registry = new SimMessagingServiceRegistry();
        registry.setException(new MessagingException(null, -1, null, null));
        
        SimMessagingService messagingService = new SimMessagingService();
        messagingService.setId("com.openexchange.test");
        
        registry.add(messagingService);
        
        AllAction action = new AllAction(registry, Translator.EMPTY);
        
        try {
            AJAXRequestResult result = action.perform(null, null);
            fail("Should not swallow exceptions");
        } catch (MessagingException x) {
            // Success
        }
    
    }
    
    
}

==> open-xchange-messaging-json_6.18.0.0.orig.tar.gz: open-xchange-messaging-json-6.18.0.0/test/com/openexchange/messaging/json/actions/services/AllActionTest.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messaging.json.actions.services;

import junit.framework.TestCase;
import org.json.JSONArray;
import com.openexchange.ajax.requesthandler.AJAXRequestResult;
import com.openexchange.groupware.AbstractOXException;
import com.openexchange.messaging.MessagingException;
import com.openexchange.messaging.SimMessagingService;
import com.openexchange.messaging.registry.SimMessagingServiceRegistry;

/**
 * {@link AllActionTest}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class AllActionTest extends TestCase {

    // Success Case
    public void testSuccess() throws AbstractOXException {
        SimMessagingServiceRegistry registry = new SimMessagingServiceRegistry();

        SimMessagingService messagingService = new SimMessagingService();
        messagingService.setId("com.openexchange.test");

        registry.add(messagingService);

        AllAction action = new AllAction(registry);

        AJAXRequestResult result = action.perform(null, null);

        assertNotNull(result);

        Object resultObject = result.getResultObject();
        assertNotNull(resultObject);

        assertTrue(JSONArray.class.isInstance(resultObject));

        JSONArray all = (JSONArray) resultObject;
        assertEquals(1, all.length());
    }

    // Error Cases

    public void testMessagingException() throws AbstractOXException {
        SimMessagingServiceRegistry registry = new SimMessagingServiceRegistry();
        registry.setException(new MessagingException(null, -1, null, null));

        SimMessagingService messagingService = new SimMessagingService();
        messagingService.setId("com.openexchange.test");

        registry.add(messagingService);

        AllAction action = new AllAction(registry);

        try {
            AJAXRequestResult result = action.perform(null, null);
            fail("Should not swallow exceptions");
            assertNull(result);
        } catch (MessagingException x) {
            // Success
        }
    }
}
